import re


def slugify(value):
    """
    Normalizes string, converts to lowercase, removes non-alpha characters,
    and converts spaces to hyphens.
    """
    import unicodedata
    value = unicode(value)
    value = unicodedata.normalize('NFKD', value).encode('ascii', 'ignore')
    value = unicode(re.sub('[^\w\s-]', '', value).strip().lower())
    return re.sub('[-\s]+', '-', value)


def sort_video_links(video_links):
    return sorted(video_links, key=lambda k: re.search(r'\d+', k['res']).group())



import copy
import json

import requests

from base import BaseDiziCrawler
from pyquery import PyQuery as pq


class DizilabCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://dizilab.net/" + self.episode['dizi_url'] + "/sezon-" + \
               str(self.episode['season']) + "/bolum-" + str(self.episode['episode'])

    def after_body_loaded(self, text):
        ajax_headers = copy.copy(BaseDiziCrawler.headers)
        ajax_headers['X-Requested-With'] = 'XMLHttpRequest'
        ajax_headers['Referer'] = self.generate_episode_page_url()

        page_dom = pq(text)
        kaynak = page_dom('.language.alternative').find('a').eq(0).attr('onclick')
        vid = kaynak[11:23]

        result = requests.post("http://dizilab.net/request/php/",
                               data={"vid": vid, "tip": "1", "type": "loadVideo"},
                               headers=ajax_headers)

        if result.status_code == 200:
            self.after_sources_loaded(result.text)

        self.episode['site'] = 'dizilab'

    def after_sources_loaded(self, text):
        sources = json.loads(text)['sources']
        for source in sources:
            video_link = {"res": source['label'], "url": source['file']}
            self.episode['video_links'].append(video_link)





import vizontele
from diziay import DiziayCrawler
from dizibox import DiziboxCrawler
from dizilab import DizilabCrawler
from dizipub import DizipubCrawler
from dizist import DizistCrawler
from sezonlukdizi import SezonlukDiziCrawler
from dizimag import DizimagCrawler

dizisites = {
    "dizilab": DizilabCrawler,
    "dizipub": DizipubCrawler,
    "sezonlukdizi": SezonlukDiziCrawler,
    "dizimag": DizimagCrawler,
    "dizibox": DiziboxCrawler,
    "diziay": DiziayCrawler,
    "dizist": DizistCrawler
}


class Crawler:
    def __init__(self, site, dizi_url, season_number, episode_number):
        self.site = site
        if self.site in dizisites.keys():
            self.dizicrawler = dizisites[self.site]()
        elif self.site == '':
            self.dizicrawler = None

        self.episode = {"dizi_url": vizontele.slugify(dizi_url),
                        "season": season_number,
                        "episode": episode_number}

    def get_sources(self):
        if self.dizicrawler is not None:
            self.episode = self.dizicrawler.get_sources(self.episode)
        else:
            # Site is not specified, lets check them all
            for site in dizisites.keys():
                self.dizicrawler = dizisites[site]()
                self.episode = self.dizicrawler.get_sources(self.episode)
                if 'video_links' in self.dizicrawler.episode and len(self.dizicrawler.episode['video_links']) > 0:
                    break

        return self.episode




#!/usr/bin/env python
from distutils.core import setup
from setuptools import find_packages

setup(
    name='vizontele',
    version='0.0.3',
    description='A tool to crawl and get sources of TV Shows from various Turkish web sites.',
    author='Halil Ozercan',
    author_email='halilozercan@gmail',
    url='https://github.com/halilozercan/vizontele',
    download_url='https://github.com/halilozercan/vizontele/tarball/0.0.3',
    entry_points={
        'console_scripts': [
            'vizontele = vizontele.bin:main',
        ],
    },
    install_requires=['requests', 'wheel', 'pyquery', 'demjson', 'pget', 'furl'],
    packages=find_packages(exclude=("tests", "tests.*")),
)
